package ru.ulstu.report.controller;

import jakarta.validation.Valid;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import ru.ulstu.aspirant.service.AspirantService;
import ru.ulstu.report.model.dto.ReportValueDto;
import ru.ulstu.report.service.ReportValueService;

import java.io.IOException;

@Controller
@RequestMapping("report-value")
public class ReportValueController {
    private final ReportValueService reportValueService;
    private final AspirantService aspirantService;

    public ReportValueController(ReportValueService reportValueService, AspirantService aspirantService) {
        this.reportValueService = reportValueService;
        this.aspirantService = aspirantService;
    }

    @GetMapping("edit-report-value/{reportId}/{indicatorId}")
    public String getReportValue(@PathVariable("reportId") Integer reportId,
                                 @PathVariable("indicatorId") Integer indicatorId,
                                 Model model) {
        model.addAttribute("reportValue", reportValueService.getByIndicatorId(reportId, indicatorId));
        model.addAttribute("canEdit", reportValueService.canEdit(reportId));
        return "report/editReportValue";
    }

    @PostMapping("save-report-value")
    public String saveReportValue(@Valid ReportValueDto reportValueDto, Model model) throws IOException {
        reportValueService.saveReportValue(reportValueDto);
        return "redirect:/report/edit-report/" + reportValueDto.getReportId();
    }
}
